@@ -7,11 +7,8 @@ activate (GtkApplication *app,
   GtkWidget *window;
 
   window = gtk_application_window_new (app);
-
-  gtk_window_set_application (GTK_WINDOW (window), GTK_APPLICATION (app));
   gtk_window_set_title (GTK_WINDOW (window), "Hello GNOME");
-
-  gtk_widget_show_all (GTK_WIDGET (window));
+  gtk_widget_show_all (window);
 }
 
 int
@@ -20,7 +17,7 @@ main (int argc, char **argv)
   GtkApplication *app;
   int status;
 
-  app = gtk_application_new ("org.gtk.example",G_APPLICATION_FLAGS_NONE);
+  app = gtk_application_new ("org.gtk.example", G_APPLICATION_FLAGS_NONE);
   g_signal_connect (app, "activate", G_CALLBACK (activate), NULL);
   status = g_application_run (G_APPLICATION (app), argc, argv);
   g_object_unref (app);
